
       PROGRAM MAIN
C
C Calculation of the change in grain surface area per unit volume
C   and grain edge length per unit volume as a function of a 
C   variety of deformations.
C
C H. K. D. H. Bhadeshia, University of Cambridge, 2006
C 
C The original separate programs for each deformation have been 
C  combined into one by Jae-Young Chae, GIFT, POSTECH

       INTEGER SEL

C Menu for selection of type of deformation

C Print the MENU

 50    CONTINUE
       WRITE(*,*) 'Select deformation type:'
       WRITE(*,*) '   1 : Plane strain deformation of plates'
       WRITE(*,*) '   2 : Plane strain deformation of oriented plates'
       WRITE(*,*) '   3 : Axisymmetric compression of tetrakaidecahedra'
       WRITE(*,*) '   4 : Plane strain deformation of tetrakaidecahedra'
       WRITE(*,*) '   5 : Cross rolling of tetrakaidecahedra'
       WRITE(*,*) '   6 : Shear of tetrakaidecahedra'
       WRITE(*,*) '   7 : Axisymmetric tension of tetrakaidecahedra'
       WRITE(*,*) '   8 : Plane strain deformation combined with Shear'
       WRITE(*,*) '       of tetrakaidecahedra'
       WRITE(*,*) '   9 : Plane strain deformation of Needle'
       WRITE(*,*) '0 : QUIT'
       READ(*,*) SEL

C Loop until user choose 'QUIT'.

       IF    (SEL .EQ. 1) THEN
        CALL pPS1()
       ELSEIF(SEL .EQ. 2) THEN
        CALL pPS2()
       ELSEIF(SEL .EQ. 3) THEN
        CALL tAXICOMPR()
       ELSEIF(SEL .EQ. 4) THEN
        CALL tPS()
       ELSEIF(SEL .EQ. 5) THEN
        CALL tCR()
       ELSEIF(SEL .EQ. 6) THEN
        CALL tS()
       ELSEIF(SEL .EQ. 7) THEN
        CALL tA()
       ELSEIF(SEL .EQ. 8) THEN
        CALL tsPS()
       ELSEIF(SEL .EQ. 9) THEN
        CALL pPSNEEDLE()
       ELSEIF(SEL .EQ. 0) THEN
        GOTO 60
       ELSE
        WRITE(*,*) 'Wrong Input!'
       ENDIF

       GOTO 50

60     CONTINUE
       STOP
       END

C Each one of seven original programs is now a SUBROUTINE

C*****************************************************************
C SUBROUTINE for plane strain deformation of plate-shaped grains
C  Plates are randomly oriented with respect to the 
C  deformation axes.
C*****************************************************************
       SUBROUTINE pPS1()
        DOUBLE PRECISION S(9)
        DOUBLE PRECISION A1(3),A2(3),A3(3)
        DOUBLE PRECISION B1(3),B2(3),B3(3)
        DOUBLE PRECISION C1(3),C2(3),C3(3)
        DOUBLE PRECISION D1(3),D2(3),D3(3)
        DOUBLE PRECISION AREA1,AREA2,AREA3
        DOUBLE PRECISION A,B,C,AREATOT,AREARATIO
        DOUBLE PRECISION LENTOT,L1,L2,L3,L4,L5,L6,LRATIO
        DOUBLE PRECISION S1,S9,E1,E2,E3,ES
        DOUBLE PRECISION R(9),P1,P2,P3,N,P
        INTEGER I,J       
C
C FOR PRINTING SIGNATURE OF THIS ROUTINE     
        CALL SIGPRINT(' Plane strain deformation of plate-shaped grains'
     &               ,'Plates are randomly oriented with respect       '
     &               ,'to the deformation axes                         '
     &               ,.FALSE.)
      
       WRITE(*,3)

C THE THREE VECTORS OF A PLATE, z being the thickness direction
C
       DO 4 J=1,100
C       
       IF(J .EQ. 1)THEN
       A1(1)=1.0D+00
       A1(2)=0.0D+00
       A1(3)=0.0D+00
C
       A2(1)=0.0D+00
       A2(2)=1.0D+00
       A2(3)=0.0D+00
C
       A3(1)=0.0D+00
       A3(2)=0.0D+00
       A3(3)=0.05D+00

      
C
       ELSE
       
       P1=RAND()
       P2=RAND()
       P3=RAND()
       P=DSQRT(P1*P1+P2*P2+P3*P3)
       P1=P1/P
       P2=P2/P
       P3=P3/P
       N=2*3.14159*RAND()
       CALL ROT(P1,P2,P3,N,R)
       
       
       D1(1)=1.0D+00
       D1(2)=0.0D+00
       D1(3)=0.0D+00
C
       D2(1)=0.0D+00
       D2(2)=1.0D+00
       D2(3)=0.0D+00
C
       D3(1)=0.0D+00
       D3(2)=0.0D+00
       D3(3)=0.05D+00

       CALL TRANS(R,D1(1),D1(2),D1(3),A1(1),A1(2),A1(3))
       CALL TRANS(R,D2(1),D2(2),D2(3),A2(1),A2(2),A2(3))
       CALL TRANS(R,D3(1),D3(2),D3(3),A3(1),A3(2),A3(3))
       ENDIF
C
C vary strain
      DO 2 I=1,12
         S1=I*1.0D+00
         S9=1.0D+00/S1
C
C DEFORMATION MATRIX
       S(1)=1.0d+00*S1
       S(2)=0.0d+00
       S(3)=0.0d+00
       S(4)=0.0d+00
       S(5)=1.0D+00
       S(6)=0.0D+00
       S(7)=0.0D+00
       S(8)=0.0D+00
       S(9)=1.0D+00*S9
       E1=DLOG(S(1))
       E2=DLOG(S(5))
       E3=DLOG(S(9))
       ES=DSQRT((2.0D+00/3.0D+00)*(E1*E1+E2*E2+E3*E3))
       
C
C VECTORS AFTER DEFORMATION
       CALL TRANS(S,A1(1),A1(2),A1(3),B1(1),B1(2),B1(3))
       CALL TRANS(S,A2(1),A2(2),A2(3),B2(1),B2(2),B2(3))
       CALL TRANS(S,A3(1),A3(2),A3(3),B3(1),B3(2),B3(3))
C
C AREA DUE TO RECTAngles
       CALL CROSS(B1(1),B1(2),B1(3),B2(1),B2(2),B2(3),A,B,C)
       CALL MAG(A,B,C,AREA1)
       CALL CROSS(B2(1),B2(2),B2(3),B3(1),B3(2),B3(3),A,B,C)
       CALL MAG(A,B,C,AREA2)
       CALL CROSS(B3(1),B3(2),B3(3),B1(1),B1(2),B1(3),A,B,C)
       CALL MAG(A,B,C,AREA3)    
       
C
C
        AREATOT=AREA1+AREA2+AREA3
        AREATOT=2*AREATOT
        AREARATIO=AREATOT/(2*(1+0.05+0.05))
C
C LENGTH
        CALL MAG(B1(1),B1(2),B1(3),L1)
        CALL MAG(B2(1),B2(2),B2(3),L2)
        CALL MAG(B3(1),B3(2),B3(3),L3)
        LENTOT=2*(L1+L2+L3)
        LRATIO=LENTOT/(2*(1+1+0.05))
C        
C

        WRITE(*,1)LRATIO,AREARATIO,E1,ES
2       CONTINUE
4       CONTINUE
1       FORMAT(4f10.2)
3       FORMAT('    L/L_0     A/A_0     STRAIN   EQ.STRAIN')

        RETURN
        END
C
C

C*****************************************************************
C SUBROUTINE for plane strain deformation of plate-shaped grains
C  Considers deformation of three specific orientations of plates
C  with respect to the deformation axes.
C*****************************************************************
       SUBROUTINE pPS2()
        DOUBLE PRECISION S(9)
        DOUBLE PRECISION A1(3),A2(3),A3(3)
        DOUBLE PRECISION B1(3),B2(3),B3(3)
        DOUBLE PRECISION C1(3),C2(3),C3(3)
        DOUBLE PRECISION D1(3),D2(3),D3(3)
        DOUBLE PRECISION AREA1,AREA2,AREA3
        DOUBLE PRECISION A,B,C,AREATOT,AREARATIO
        DOUBLE PRECISION LENTOT,L1,L2,L3,L4,L5,L6,LRATIO
        DOUBLE PRECISION S1,S9,E1,E2,E3,ES
        DOUBLE PRECISION R(9),P1,P2,P3,N,P
        INTEGER I,J

C
        CALL SIGPRINT(' Plane strain deformation of plate-shaped grains'
     &               ,'Considers deformation of 3 specific orientations'
     &               ,'of plates with respect to the deformation axes. '
     &               ,.FALSE.)

      WRITE(*,3)

       DO 4 J=1,3
C   thickness along z    
       IF(J .EQ. 1) THEN
       A1(1)=1.0D+00
       A1(2)=0.0D+00
       A1(3)=0.0D+00
C
       A2(1)=0.0D+00
       A2(2)=1.0D+00
       A2(3)=0.0D+00
C
       A3(1)=0.0D+00
       A3(2)=0.0D+00
       A3(3)=0.05D+00
       ENDIF

C   thickness along x    
       IF(J .EQ. 2)THEN
       A1(1)=0.0D+00
       A1(2)=0.0D+00
       A1(3)=1.0D+00
C
       A2(1)=0.0D+00
       A2(2)=1.0D+00
       A2(3)=0.0D+00
C
       A3(1)=0.05D+00
       A3(2)=0.0D+00
       A3(3)=0.0D+00
       ENDIF
C   thickness along y
       IF(J .EQ. 3)THEN
       A1(1)=0.0D+00
       A1(2)=0.0D+00
       A1(3)=1.0D+00
C
       A2(1)=0.0D+00
       A2(2)=0.05D+00
       A2(3)=0.0D+00
C
       A3(1)=1.0D+00
       A3(2)=0.0D+00
       A3(3)=0.0D+00   
       ENDIF

C
C vary strain
      DO 2 I=1,12
         S1=I*1.0D+00
         S9=1.0D+00/S1
C
C DEFORMATION MATRIX
       S(1)=1.0d+00*S1
       S(2)=0.0d+00
       S(3)=0.0d+00
       S(4)=0.0d+00
       S(5)=1.0D+00
       S(6)=0.0D+00
       S(7)=0.0D+00
       S(8)=0.0D+00
       S(9)=1.0D+00*S9
       E1=DLOG(S(1))
       E2=DLOG(S(5))
       E3=DLOG(S(9))
       ES=DSQRT((2.0D+00/3.0D+00)*(E1*E1+E2*E2+E3*E3))
       
C
C VECTORS AFTER DEFORMATION
       CALL TRANS(S,A1(1),A1(2),A1(3),B1(1),B1(2),B1(3))
       CALL TRANS(S,A2(1),A2(2),A2(3),B2(1),B2(2),B2(3))
       CALL TRANS(S,A3(1),A3(2),A3(3),B3(1),B3(2),B3(3))
C
C AREA DUE TO RECTAngles
       CALL CROSS(B1(1),B1(2),B1(3),B2(1),B2(2),B2(3),A,B,C)
       CALL MAG(A,B,C,AREA1)
       CALL CROSS(B2(1),B2(2),B2(3),B3(1),B3(2),B3(3),A,B,C)
       CALL MAG(A,B,C,AREA2)
       CALL CROSS(B3(1),B3(2),B3(3),B1(1),B1(2),B1(3),A,B,C)
       CALL MAG(A,B,C,AREA3)    
       
C
C
        AREATOT=AREA1+AREA2+AREA3
        AREATOT=2*AREATOT
        AREARATIO=AREATOT/(2*(1+0.05+0.05))
C
C LENGTH
        CALL MAG(B1(1),B1(2),B1(3),L1)
        CALL MAG(B2(1),B2(2),B2(3),L2)
        CALL MAG(B3(1),B3(2),B3(3),L3)
        LENTOT=2*(L1+L2+L3)
        LRATIO=LENTOT/(2*(1+1+0.05))
C        
C

        WRITE(*,1)LRATIO,AREARATIO,E1,ES
2       CONTINUE
4       CONTINUE
1       FORMAT(4f10.2)
3       FORMAT('    L/L_0     A/A_0     STRAIN    EQ.STRAIN')
 
        RETURN
        END
C
C
C**********************************************************************
C SUBROUTINE for axisymmetric compression of randomly oriented 
C  tetrakaidecahedra. 
C The first tetrakaidecahedron is oriented as in 
C  the following reference:
C  S. B. Singh and H. K. D. H. Bhadeshia
C  Materials Science & Technology 14 (1998) 832-834.
C**********************************************************************
       SUBROUTINE tAXICOMPR()
        DOUBLE PRECISION S(9)
        DOUBLE PRECISION A1(3),A2(3),A3(3),A4(3),A5(3),A6(3)
        DOUBLE PRECISION B1(3),B2(3),B3(3),B4(3),B5(3),B6(3)
        DOUBLE PRECISION C1(3),C2(3),C3(3),C4(3),C5(3),C6(3)
        DOUBLE PRECISION D1(3),D2(3),D3(3),D4(4),D5(3),D6(3)
        DOUBLE PRECISION AREA1,AREA2,AREA3,AREA4,AREA5,AREA6
        DOUBLE PRECISION AREA7,AREA8,AREA9,AREA10,AREA11,AREA12
        DOUBLE PRECISION AREA13, AREA14,AREA15
        DOUBLE PRECISION A,B,C,AREATOT,AREARATIO
        DOUBLE PRECISION LENTOT,L1,L2,L3,L4,L5,L6,LRATIO
        DOUBLE PRECISION S1,E1,E2,E3,ES
        DOUBLE PRECISION R(9),P1,P2,P3,N,P
        INTEGER I,J
       
C
       CALL SIGPRINT(' Axisymmetric compression                        '
     &              ,'','',.TRUE.)
    
      WRITE(*,3)

C THE SIX VECTORS OF TETRAKAIDECAHEDRON
C S. B. Singh and H. K. D. H. Bhadeshia
C Materials Science & Technology 14 (1998) 832-834
       DO 4 J=1,100
C       
       IF(J .EQ. 1)THEN
       A1(1)=1.0D+00
       A1(2)=0.0D+00
       A1(3)=0.0D+00
C
       A2(1)=0.0D+00
       A2(2)=1.0D+00
       A2(3)=0.0D+00
C
       A3(1)=-0.5D+00
       A3(2)=-0.5D+00
       A3(3)=1/DSQRT(2.0D+00)
C
       A4(1)=0.5D+00
       A4(2)=-0.5D+00
       A4(3)=1/DSQRT(2.0D+00)
C       
       A5(1)=0.5D+00
       A5(2)=0.5D+00
       A5(3)=1/DSQRT(2.0D+00)
C       
       A6(1)=-0.5D+00
       A6(2)=0.5D+00
       A6(3)=1/DSQRT(2.0D+00)
      
C
       ELSE
       
       P1=RAND()
       P2=RAND()
       P3=RAND()
       P=DSQRT(P1*P1+P2*P2+P3*P3)
       P1=P1/P
       P2=P2/P
       P3=P3/P
       N=2*3.14159*RAND()
       CALL ROT(P1,P2,P3,N,R)
       
       
       D1(1)=1.0D+00
       D1(2)=0.0D+00
       D1(3)=0.0D+00
C
       D2(1)=0.0D+00
       D2(2)=1.0D+00
       D2(3)=0.0D+00
C
       D3(1)=-0.5D+00
       D3(2)=-0.5D+00
       D3(3)=1/DSQRT(2.0D+00)
C
       D4(1)=0.5D+00
       D4(2)=-0.5D+00
       D4(3)=1/DSQRT(2.0D+00)
C       
       D5(1)=0.5D+00
       D5(2)=0.5D+00
       D5(3)=1/DSQRT(2.0D+00)
C       
       D6(1)=-0.5D+00
       D6(2)=0.5D+00
       D6(3)=1/DSQRT(2.0D+00)
C
       CALL TRANS(R,D1(1),D1(2),D1(3),A1(1),A1(2),A1(3))
       CALL TRANS(R,D2(1),D2(2),D2(3),A2(1),A2(2),A2(3))
       CALL TRANS(R,D3(1),D3(2),D3(3),A3(1),A3(2),A3(3))
       CALL TRANS(R,D4(1),D4(2),D4(3),A4(1),A4(2),A4(3))
       CALL TRANS(R,D5(1),D5(2),D5(3),A5(1),A5(2),A5(3))
       CALL TRANS(R,D6(1),D6(2),D6(3),A6(1),A6(2),A6(3))
       ENDIF
C
      DO 2 I=1,16
       S1=(I)*1.0D+00
         
C
C DEFORMATION MATRIX
       S(9)=1.0D+00/S1
       S(1)=1.0d+00/DSQRT(S(9))
       S(2)=0.0d+00
       S(3)=0.0D+00
       S(4)=0.0d+00
       S(5)=1.0d+00/DSQRT(S(9))
       S(6)=0.0D+00
       S(7)=0.0D+00
       S(8)=0.0D+00



       E1=DLOG(S(1))
       E2=DLOG(S(5))
       E3=DLOG(S(9))
       ES=DSQRT((2.0D+00/3.0D+00)*(E1*E1+E2*E2+E3*E3))
       
C
C VECTORS AFTER DEFORMATION
       CALL TRANS(S,A1(1),A1(2),A1(3),B1(1),B1(2),B1(3))
       CALL TRANS(S,A2(1),A2(2),A2(3),B2(1),B2(2),B2(3))
       CALL TRANS(S,A3(1),A3(2),A3(3),B3(1),B3(2),B3(3))
       CALL TRANS(S,A4(1),A4(2),A4(3),B4(1),B4(2),B4(3))
       CALL TRANS(S,A5(1),A5(2),A5(3),B5(1),B5(2),B5(3))
       CALL TRANS(S,A6(1),A6(2),A6(3),B6(1),B6(2),B6(3))
C
C AREA DUE TO SQUARES
       CALL CROSS(B1(1),B1(2),B1(3),B2(1),B2(2),B2(3),A,B,C)
       CALL MAG(A,B,C,AREA1)
       CALL CROSS(B3(1),B3(2),B3(3),B5(1),B5(2),B5(3),A,B,C)
       CALL MAG(A,B,C,AREA2)
       CALL CROSS(B4(1),B4(2),B4(3),B6(1),B6(2),B6(3),A,B,C)
       CALL MAG(A,B,C,AREA3)    
       
C
C AREA DUE TO HEXAGONS
        CALL CROSS(B1(1),B1(2),B1(3),B3(1),B3(2),B3(3),A,B,C)
        CALL MAG(A,B,C,AREA4)
        CALL CROSS(B1(1),B1(2),B1(3),B4(1),B4(2),B4(3),A,B,C)
        CALL MAG(A,B,C,AREA5)
        CALL CROSS(B3(1),B3(2),B3(3),B4(1),B4(2),B4(3),A,B,C)
        CALL MAG(A,B,C,AREA6)
C        
        CALL CROSS(B1(1),B1(2),B1(3),B5(1),B5(2),B5(3),A,B,C)
        CALL MAG(A,B,C,AREA7)
        CALL CROSS(B1(1),B1(2),B1(3),B6(1),B6(2),B6(3),A,B,C)
        CALL MAG(A,B,C,AREA8)
        CALL CROSS(B5(1),B5(2),B5(3),B6(1),B6(2),B6(3),A,B,C)
        CALL MAG(A,B,C,AREA9)
C        
        CALL CROSS(B2(1),B2(2),B2(3),B3(1),B3(2),B3(3),A,B,C)
        CALL MAG(A,B,C,AREA10)
        CALL CROSS(B2(1),B2(2),B2(3),B6(1),B6(2),B6(3),A,B,C)
        CALL MAG(A,B,C,AREA11)
        CALL CROSS(B3(1),B3(2),B3(3),B6(1),B6(2),B6(3),A,B,C)
        CALL MAG(A,B,C,AREA12)
C        
        CALL CROSS(B2(1),B2(2),B2(3),B5(1),B5(2),B5(3),A,B,C)
        CALL MAG(A,B,C,AREA13)
        CALL CROSS(B2(1),B2(2),B2(3),B4(1),B4(2),B4(3),A,B,C)
        CALL MAG(A,B,C,AREA14)
        CALL CROSS(B5(1),B5(2),B5(3),B4(1),B4(2),B4(3),A,B,C)
C
        CALL MAG(A,B,C,AREA15)
        AREATOT=AREA1+AREA2+AREA3
     &     +AREA4+AREA5+AREA6+AREA7+AREA8+AREA9+AREA10
     &     +AREA11+AREA12+AREA13+AREA14+AREA15
        AREATOT=2*AREATOT
        AREARATIO=AREATOT/(6*(1.0+2*DSQRT(3.0D+00)))
C
C LENGTH
        CALL MAG(B1(1),B1(2),B1(3),L1)
        CALL MAG(B2(1),B2(2),B2(3),L2)
        CALL MAG(B3(1),B3(2),B3(3),L3)
        CALL MAG(B4(1),B4(2),B4(3),L4)
        CALL MAG(B5(1),B5(2),B5(3),L5)
        CALL MAG(B6(1),B6(2),B6(3),L6)
        LENTOT=6*(L1+L2+L3+L4+L5+L6)
        LRATIO=LENTOT/36.0D+00
C        
C

        WRITE(*,1)LRATIO,AREARATIO,E1,E2,E3,ES
2       CONTINUE
4       CONTINUE
1       FORMAT(6f10.2)
3       FORMAT('    L/L_0     A/A_0     S_11      S_22      S_33 
     &Eq')

        RETURN
        END
C
C
C
C**********************************************************************
C SUBROUTINE for plane strain deformation of randomly oriented 
C  tetrakaidecahedra.
C The first tetrakaidecahedron is oriented as in 
C  the following reference:
C  S. B. Singh and H. K. D. H. Bhadeshia
C  Materials Science & Technology 14 (1998) 832-834.
C**********************************************************************
       SUBROUTINE tPS()
        DOUBLE PRECISION S(9)
        DOUBLE PRECISION A1(3),A2(3),A3(3),A4(3),A5(3),A6(3)
        DOUBLE PRECISION B1(3),B2(3),B3(3),B4(3),B5(3),B6(3)
        DOUBLE PRECISION C1(3),C2(3),C3(3),C4(3),C5(3),C6(3)
        DOUBLE PRECISION D1(3),D2(3),D3(3),D4(4),D5(3),D6(3)
        DOUBLE PRECISION AREA1,AREA2,AREA3,AREA4,AREA5,AREA6
        DOUBLE PRECISION AREA7,AREA8,AREA9,AREA10,AREA11,AREA12
        DOUBLE PRECISION AREA13, AREA14,AREA15
        DOUBLE PRECISION A,B,C,AREATOT,AREARATIO
        DOUBLE PRECISION LENTOT,L1,L2,L3,L4,L5,L6,LRATIO
        DOUBLE PRECISION S1,S9,E1,E2,E3,ES
        DOUBLE PRECISION R(9),P1,P2,P3,N,P
        INTEGER I,J
       
C   
      CALL SIGPRINT(' Plane strain deformation                        '
     &             ,'','',.TRUE.)
 
      WRITE(*,3)

C THE SIX VECTORS OF TETRAKAIDECAHEDRON
C S. B. Singh and H. K. D. H. Bhadeshia
C Materials Science & Technology 14 (1998) 832-834
       DO 4 J=1,100
C       
       IF(J .EQ. 1)THEN
       A1(1)=1.0D+00
       A1(2)=0.0D+00
       A1(3)=0.0D+00
C
       A2(1)=0.0D+00
       A2(2)=1.0D+00
       A2(3)=0.0D+00
C
       A3(1)=-0.5D+00
       A3(2)=-0.5D+00
       A3(3)=1/DSQRT(2.0D+00)
C
       A4(1)=0.5D+00
       A4(2)=-0.5D+00
       A4(3)=1/DSQRT(2.0D+00)
C       
       A5(1)=0.5D+00
       A5(2)=0.5D+00
       A5(3)=1/DSQRT(2.0D+00)
C       
       A6(1)=-0.5D+00
       A6(2)=0.5D+00
       A6(3)=1/DSQRT(2.0D+00)
      
C
       ELSE
       
       P1=RAND()
       P2=RAND()
       P3=RAND()
       P=DSQRT(P1*P1+P2*P2+P3*P3)
       P1=P1/P
       P2=P2/P
       P3=P3/P
       N=2*3.14159*RAND()
       CALL ROT(P1,P2,P3,N,R)
       
       
       D1(1)=1.0D+00
       D1(2)=0.0D+00
       D1(3)=0.0D+00
C
       D2(1)=0.0D+00
       D2(2)=1.0D+00
       D2(3)=0.0D+00
C
       D3(1)=-0.5D+00
       D3(2)=-0.5D+00
       D3(3)=1/DSQRT(2.0D+00)
C
       D4(1)=0.5D+00
       D4(2)=-0.5D+00
       D4(3)=1/DSQRT(2.0D+00)
C       
       D5(1)=0.5D+00
       D5(2)=0.5D+00
       D5(3)=1/DSQRT(2.0D+00)
C       
       D6(1)=-0.5D+00
       D6(2)=0.5D+00
       D6(3)=1/DSQRT(2.0D+00)
C
       CALL TRANS(R,D1(1),D1(2),D1(3),A1(1),A1(2),A1(3))
       CALL TRANS(R,D2(1),D2(2),D2(3),A2(1),A2(2),A2(3))
       CALL TRANS(R,D3(1),D3(2),D3(3),A3(1),A3(2),A3(3))
       CALL TRANS(R,D4(1),D4(2),D4(3),A4(1),A4(2),A4(3))
       CALL TRANS(R,D5(1),D5(2),D5(3),A5(1),A5(2),A5(3))
       CALL TRANS(R,D6(1),D6(2),D6(3),A6(1),A6(2),A6(3))
       ENDIF
C
      DO 2 I=1,12
         S1=I*1.0D+00
         S9=1.0D+00/S1
C
C DEFORMATION MATRIX
       S(1)=1.0d+00*S1
       S(2)=0.0d+00
       S(3)=0.0d+00
       S(4)=0.0d+00
       S(5)=1.0D+00
       S(6)=0.0D+00
       S(7)=0.0D+00
       S(8)=0.0D+00
       S(9)=1.0D+00*S9
       E1=DLOG(S(1))
       E2=DLOG(S(5))
       E3=DLOG(S(9))
       ES=DSQRT((2.0D+00/3.0D+00)*(E1*E1+E2*E2+E3*E3))
       
C
C VECTORS AFTER DEFORMATION
       CALL TRANS(S,A1(1),A1(2),A1(3),B1(1),B1(2),B1(3))
       CALL TRANS(S,A2(1),A2(2),A2(3),B2(1),B2(2),B2(3))
       CALL TRANS(S,A3(1),A3(2),A3(3),B3(1),B3(2),B3(3))
       CALL TRANS(S,A4(1),A4(2),A4(3),B4(1),B4(2),B4(3))
       CALL TRANS(S,A5(1),A5(2),A5(3),B5(1),B5(2),B5(3))
       CALL TRANS(S,A6(1),A6(2),A6(3),B6(1),B6(2),B6(3))
C
C AREA DUE TO SQUARES
       CALL CROSS(B1(1),B1(2),B1(3),B2(1),B2(2),B2(3),A,B,C)
       CALL MAG(A,B,C,AREA1)
       CALL CROSS(B3(1),B3(2),B3(3),B5(1),B5(2),B5(3),A,B,C)
       CALL MAG(A,B,C,AREA2)
       CALL CROSS(B4(1),B4(2),B4(3),B6(1),B6(2),B6(3),A,B,C)
       CALL MAG(A,B,C,AREA3)    
       
C
C AREA DUE TO HEXAGONS
        CALL CROSS(B1(1),B1(2),B1(3),B3(1),B3(2),B3(3),A,B,C)
        CALL MAG(A,B,C,AREA4)
        CALL CROSS(B1(1),B1(2),B1(3),B4(1),B4(2),B4(3),A,B,C)
        CALL MAG(A,B,C,AREA5)
        CALL CROSS(B3(1),B3(2),B3(3),B4(1),B4(2),B4(3),A,B,C)
        CALL MAG(A,B,C,AREA6)
C        
        CALL CROSS(B1(1),B1(2),B1(3),B5(1),B5(2),B5(3),A,B,C)
        CALL MAG(A,B,C,AREA7)
        CALL CROSS(B1(1),B1(2),B1(3),B6(1),B6(2),B6(3),A,B,C)
        CALL MAG(A,B,C,AREA8)
        CALL CROSS(B5(1),B5(2),B5(3),B6(1),B6(2),B6(3),A,B,C)
        CALL MAG(A,B,C,AREA9)
C        
        CALL CROSS(B2(1),B2(2),B2(3),B3(1),B3(2),B3(3),A,B,C)
        CALL MAG(A,B,C,AREA10)
        CALL CROSS(B2(1),B2(2),B2(3),B6(1),B6(2),B6(3),A,B,C)
        CALL MAG(A,B,C,AREA11)
        CALL CROSS(B3(1),B3(2),B3(3),B6(1),B6(2),B6(3),A,B,C)
        CALL MAG(A,B,C,AREA12)
C        
        CALL CROSS(B2(1),B2(2),B2(3),B5(1),B5(2),B5(3),A,B,C)
        CALL MAG(A,B,C,AREA13)
        CALL CROSS(B2(1),B2(2),B2(3),B4(1),B4(2),B4(3),A,B,C)
        CALL MAG(A,B,C,AREA14)
        CALL CROSS(B5(1),B5(2),B5(3),B4(1),B4(2),B4(3),A,B,C)
C
        CALL MAG(A,B,C,AREA15)
        AREATOT=AREA1+AREA2+AREA3
     &     +AREA4+AREA5+AREA6+AREA7+AREA8+AREA9+AREA10
     &     +AREA11+AREA12+AREA13+AREA14+AREA15
        AREATOT=2*AREATOT
        AREARATIO=AREATOT/(6*(1.0+2*DSQRT(3.0D+00)))
C
C LENGTH
        CALL MAG(B1(1),B1(2),B1(3),L1)
        CALL MAG(B2(1),B2(2),B2(3),L2)
        CALL MAG(B3(1),B3(2),B3(3),L3)
        CALL MAG(B4(1),B4(2),B4(3),L4)
        CALL MAG(B5(1),B5(2),B5(3),L5)
        CALL MAG(B6(1),B6(2),B6(3),L6)
        LENTOT=6*(L1+L2+L3+L4+L5+L6)
        LRATIO=LENTOT/36.0D+00
C        
C

        WRITE(*,1)LRATIO,AREARATIO,E1,ES
2       CONTINUE
4       CONTINUE
1       FORMAT(4f10.2)
3       FORMAT('    L/L_0     A/A_0     STRAIN   EQ.STRAIN')

        RETURN
        END
C
C
C
C**********************************************************************
C SUBROUTINE for cross rolling of randomly oriented tetrakaidecahedra. 
C The first tetrakaidecahedron is oriented as in 
C  the following reference:
C  S. B. Singh and H. K. D. H. Bhadeshia
C  Materials Science & Technology 14 (1998) 832-834.
C**********************************************************************
C
       SUBROUTINE tCR()
        DOUBLE PRECISION S(9),T(9),U(9),R(9)
        DOUBLE PRECISION A1(3),A2(3),A3(3),A4(3),A5(3),A6(3)
        DOUBLE PRECISION B1(3),B2(3),B3(3),B4(3),B5(3),B6(3)
        DOUBLE PRECISION C1(3),C2(3),C3(3),C4(3),C5(3),C6(3)
        DOUBLE PRECISION D1(3),D2(3),D3(3),D4(4),D5(3),D6(3)
        DOUBLE PRECISION AREA1,AREA2,AREA3,AREA4,AREA5,AREA6
        DOUBLE PRECISION AREA7,AREA8,AREA9,AREA10,AREA11,AREA12
        DOUBLE PRECISION AREA13, AREA14,AREA15
        DOUBLE PRECISION A,B,C,AREATOT,AREARATIO
        DOUBLE PRECISION LENTOT,L1,L2,L3,L4,L5,L6,LRATIO
        DOUBLE PRECISION S1,S9,E1,E2,E3,ES
        DOUBLE PRECISION P1,P2,P3,N,P,d
        INTEGER I,J
       
C
      CALL SIGPRINT(' Cross rolling                                   '
     &             ,'','',.TRUE.)
    
      WRITE(*,3)

C THE SIX VECTORS OF TETRAKAIDECAHEDRON
C S. B. Singh and H. K. D. H. Bhadeshia
C Materials Science & Technology 14 (1998) 832-834
       DO 4 J=1,1
C       
       IF(J .EQ. 1)THEN
       A1(1)=1.0D+00
       A1(2)=0.0D+00
       A1(3)=0.0D+00
C
       A2(1)=0.0D+00
       A2(2)=1.0D+00
       A2(3)=0.0D+00
C
       A3(1)=-0.5D+00
       A3(2)=-0.5D+00
       A3(3)=1/DSQRT(2.0D+00)
C
       A4(1)=0.5D+00
       A4(2)=-0.5D+00
       A4(3)=1/DSQRT(2.0D+00)
C       
       A5(1)=0.5D+00
       A5(2)=0.5D+00
       A5(3)=1/DSQRT(2.0D+00)
C       
       A6(1)=-0.5D+00
       A6(2)=0.5D+00
       A6(3)=1/DSQRT(2.0D+00)
      
C
       ELSE
       
       P1=RAND()
       P2=RAND()
       P3=RAND()
       P=DSQRT(P1*P1+P2*P2+P3*P3)
       P1=P1/P
       P2=P2/P
       P3=P3/P
       N=2*3.14159*RAND()
       CALL ROT(P1,P2,P3,N,R)
       
       
       D1(1)=1.0D+00
       D1(2)=0.0D+00
       D1(3)=0.0D+00
C
       D2(1)=0.0D+00
       D2(2)=1.0D+00
       D2(3)=0.0D+00
C
       D3(1)=-0.5D+00
       D3(2)=-0.5D+00
       D3(3)=1/DSQRT(2.0D+00)
C
       D4(1)=0.5D+00
       D4(2)=-0.5D+00
       D4(3)=1/DSQRT(2.0D+00)
C       
       D5(1)=0.5D+00
       D5(2)=0.5D+00
       D5(3)=1/DSQRT(2.0D+00)
C       
       D6(1)=-0.5D+00
       D6(2)=0.5D+00
       D6(3)=1/DSQRT(2.0D+00)
C
       CALL TRANS(R,D1(1),D1(2),D1(3),A1(1),A1(2),A1(3))
       CALL TRANS(R,D2(1),D2(2),D2(3),A2(1),A2(2),A2(3))
       CALL TRANS(R,D3(1),D3(2),D3(3),A3(1),A3(2),A3(3))
       CALL TRANS(R,D4(1),D4(2),D4(3),A4(1),A4(2),A4(3))
       CALL TRANS(R,D5(1),D5(2),D5(3),A5(1),A5(2),A5(3))
       CALL TRANS(R,D6(1),D6(2),D6(3),A6(1),A6(2),A6(3))
       ENDIF
C
      DO 2 I=5,17
         S1=I*0.2D+00
         S9=1.0D+00/S1
C
C DEFORMATION MATRIX
       S(1)=1.0d+00*S1
       S(2)=0.0d+00
       S(3)=0.0d+00
       S(4)=0.0d+00
       S(5)=1.0D+00
       S(6)=0.0D+00
       S(7)=0.0D+00
       S(8)=0.0D+00
       S(9)=1.0D+00*S9

       
       R(1)=0
       R(2)=1
       R(3)=0
       R(4)=-1
       R(5)=0
       R(6)=0
       R(7)=0
       R(8)=0
       R(9)=1
       CALL PROD(T,R,S)
       CALL PROD(U,S,T)


C
C VECTORS AFTER DEFORMATION
       CALL TRANS(U,A1(1),A1(2),A1(3),B1(1),B1(2),B1(3))
       CALL TRANS(U,A2(1),A2(2),A2(3),B2(1),B2(2),B2(3))
       CALL TRANS(U,A3(1),A3(2),A3(3),B3(1),B3(2),B3(3))
       CALL TRANS(U,A4(1),A4(2),A4(3),B4(1),B4(2),B4(3))
       CALL TRANS(U,A5(1),A5(2),A5(3),B5(1),B5(2),B5(3))
       CALL TRANS(U,A6(1),A6(2),A6(3),B6(1),B6(2),B6(3))
C
C AREA DUE TO SQUARES
       CALL CROSS(B1(1),B1(2),B1(3),B2(1),B2(2),B2(3),A,B,C)
       CALL MAG(A,B,C,AREA1)
       CALL CROSS(B3(1),B3(2),B3(3),B5(1),B5(2),B5(3),A,B,C)
       CALL MAG(A,B,C,AREA2)
       CALL CROSS(B4(1),B4(2),B4(3),B6(1),B6(2),B6(3),A,B,C)
       CALL MAG(A,B,C,AREA3)    
       
C
C AREA DUE TO HEXAGONS
        CALL CROSS(B1(1),B1(2),B1(3),B3(1),B3(2),B3(3),A,B,C)
        CALL MAG(A,B,C,AREA4)
        CALL CROSS(B1(1),B1(2),B1(3),B4(1),B4(2),B4(3),A,B,C)
        CALL MAG(A,B,C,AREA5)
        CALL CROSS(B3(1),B3(2),B3(3),B4(1),B4(2),B4(3),A,B,C)
        CALL MAG(A,B,C,AREA6)
C        
        CALL CROSS(B1(1),B1(2),B1(3),B5(1),B5(2),B5(3),A,B,C)
        CALL MAG(A,B,C,AREA7)
        CALL CROSS(B1(1),B1(2),B1(3),B6(1),B6(2),B6(3),A,B,C)
        CALL MAG(A,B,C,AREA8)
        CALL CROSS(B5(1),B5(2),B5(3),B6(1),B6(2),B6(3),A,B,C)
        CALL MAG(A,B,C,AREA9)
C        
        CALL CROSS(B2(1),B2(2),B2(3),B3(1),B3(2),B3(3),A,B,C)
        CALL MAG(A,B,C,AREA10)
        CALL CROSS(B2(1),B2(2),B2(3),B6(1),B6(2),B6(3),A,B,C)
        CALL MAG(A,B,C,AREA11)
        CALL CROSS(B3(1),B3(2),B3(3),B6(1),B6(2),B6(3),A,B,C)
        CALL MAG(A,B,C,AREA12)
C        
        CALL CROSS(B2(1),B2(2),B2(3),B5(1),B5(2),B5(3),A,B,C)
        CALL MAG(A,B,C,AREA13)
        CALL CROSS(B2(1),B2(2),B2(3),B4(1),B4(2),B4(3),A,B,C)
        CALL MAG(A,B,C,AREA14)
        CALL CROSS(B5(1),B5(2),B5(3),B4(1),B4(2),B4(3),A,B,C)
C
        CALL MAG(A,B,C,AREA15)
        AREATOT=AREA1+AREA2+AREA3
     &     +AREA4+AREA5+AREA6+AREA7+AREA8+AREA9+AREA10
     &     +AREA11+AREA12+AREA13+AREA14+AREA15
        AREATOT=2*AREATOT
        AREARATIO=AREATOT/(6*(1.0+2*DSQRT(3.0D+00)))
C
C LENGTH
        CALL MAG(B1(1),B1(2),B1(3),L1)
        CALL MAG(B2(1),B2(2),B2(3),L2)
        CALL MAG(B3(1),B3(2),B3(3),L3)
        CALL MAG(B4(1),B4(2),B4(3),L4)
        CALL MAG(B5(1),B5(2),B5(3),L5)
        CALL MAG(B6(1),B6(2),B6(3),L6)
        LENTOT=6*(L1+L2+L3+L4+L5+L6)
        LRATIO=LENTOT/36.0D+00
C        
C

        WRITE(*,1)LRATIO,AREARATIO,DLOG(U(9))
2       CONTINUE
4       CONTINUE
1       FORMAT(4f10.2)
3       FORMAT('    L/L_0     A/A_0     STRAIN S33')

        RETURN
        END
C
C

C**********************************************************************
C SUBROUTINE for shear of randomly oriented tetrakaidecahedra
C The first tetrakaidecahedron is oriented as in 
C  the following reference:
C  S. B. Singh and H. K. D. H. Bhadeshia
C  Materials Science & Technology 14 (1998) 832-834.
C**********************************************************************
C
       SUBROUTINE tS()
        DOUBLE PRECISION S(9)
        DOUBLE PRECISION A1(3),A2(3),A3(3),A4(3),A5(3),A6(3)
        DOUBLE PRECISION B1(3),B2(3),B3(3),B4(3),B5(3),B6(3)
        DOUBLE PRECISION C1(3),C2(3),C3(3),C4(3),C5(3),C6(3)
        DOUBLE PRECISION D1(3),D2(3),D3(3),D4(4),D5(3),D6(3)
        DOUBLE PRECISION AREA1,AREA2,AREA3,AREA4,AREA5,AREA6
        DOUBLE PRECISION AREA7,AREA8,AREA9,AREA10,AREA11,AREA12
        DOUBLE PRECISION AREA13, AREA14,AREA15
        DOUBLE PRECISION A,B,C,AREATOT,AREARATIO
        DOUBLE PRECISION LENTOT,L1,L2,L3,L4,L5,L6,LRATIO
        DOUBLE PRECISION S3,E1,E2,E3,ES
        DOUBLE PRECISION R(9),P1,P2,P3,N,P
        INTEGER I,J
       
C    
      CALL SIGPRINT(' Shear                                           '
     &             ,'','',.TRUE.)

      WRITE(*,3)

C THE SIX VECTORS OF TETRAKAIDECAHEDRON
C S. B. Singh and H. K. D. H. Bhadeshia
C Materials Science & Technology 14 (1998) 832-834
       DO 4 J=1,100
C       
       IF(J .EQ. 1)THEN
       A1(1)=1.0D+00
       A1(2)=0.0D+00
       A1(3)=0.0D+00
C
       A2(1)=0.0D+00
       A2(2)=1.0D+00
       A2(3)=0.0D+00
C
       A3(1)=-0.5D+00
       A3(2)=-0.5D+00
       A3(3)=1/DSQRT(2.0D+00)
C
       A4(1)=0.5D+00
       A4(2)=-0.5D+00
       A4(3)=1/DSQRT(2.0D+00)
C       
       A5(1)=0.5D+00
       A5(2)=0.5D+00
       A5(3)=1/DSQRT(2.0D+00)
C       
       A6(1)=-0.5D+00
       A6(2)=0.5D+00
       A6(3)=1/DSQRT(2.0D+00)
      
C
       ELSE
       
       P1=RAND()
       P2=RAND()
       P3=RAND()
       P=DSQRT(P1*P1+P2*P2+P3*P3)
       P1=P1/P
       P2=P2/P
       P3=P3/P
       N=2*3.14159*RAND()
       CALL ROT(P1,P2,P3,N,R)
       
       
       D1(1)=1.0D+00
       D1(2)=0.0D+00
       D1(3)=0.0D+00
C
       D2(1)=0.0D+00
       D2(2)=1.0D+00
       D2(3)=0.0D+00
C
       D3(1)=-0.5D+00
       D3(2)=-0.5D+00
       D3(3)=1/DSQRT(2.0D+00)
C
       D4(1)=0.5D+00
       D4(2)=-0.5D+00
       D4(3)=1/DSQRT(2.0D+00)
C       
       D5(1)=0.5D+00
       D5(2)=0.5D+00
       D5(3)=1/DSQRT(2.0D+00)
C       
       D6(1)=-0.5D+00
       D6(2)=0.5D+00
       D6(3)=1/DSQRT(2.0D+00)
C
       CALL TRANS(R,D1(1),D1(2),D1(3),A1(1),A1(2),A1(3))
       CALL TRANS(R,D2(1),D2(2),D2(3),A2(1),A2(2),A2(3))
       CALL TRANS(R,D3(1),D3(2),D3(3),A3(1),A3(2),A3(3))
       CALL TRANS(R,D4(1),D4(2),D4(3),A4(1),A4(2),A4(3))
       CALL TRANS(R,D5(1),D5(2),D5(3),A5(1),A5(2),A5(3))
       CALL TRANS(R,D6(1),D6(2),D6(3),A6(1),A6(2),A6(3))
       ENDIF
C
      DO 2 I=1,400,10
       S3=(I-1)*1.0D+00/10.0D+00  
         
C
C DEFORMATION MATRIX
       S(1)=1.0d+00
       S(2)=0.0d+00
       S(3)=S3
       S(4)=0.0d+00
       S(5)=1.0D+00
       S(6)=0.0D+00
       S(7)=0.0D+00
       S(8)=0.0D+00
       S(9)=1.0D+00
       E1=DLOG(S(1))
       E2=DLOG(S(5))
       E3=DLOG(S(9))
       ES=DSQRT((2.0D+00/3.0D+00)*(E1*E1+E2*E2+E3*E3))
       
C
C VECTORS AFTER DEFORMATION
       CALL TRANS(S,A1(1),A1(2),A1(3),B1(1),B1(2),B1(3))
       CALL TRANS(S,A2(1),A2(2),A2(3),B2(1),B2(2),B2(3))
       CALL TRANS(S,A3(1),A3(2),A3(3),B3(1),B3(2),B3(3))
       CALL TRANS(S,A4(1),A4(2),A4(3),B4(1),B4(2),B4(3))
       CALL TRANS(S,A5(1),A5(2),A5(3),B5(1),B5(2),B5(3))
       CALL TRANS(S,A6(1),A6(2),A6(3),B6(1),B6(2),B6(3))
C
C AREA DUE TO SQUARES
       CALL CROSS(B1(1),B1(2),B1(3),B2(1),B2(2),B2(3),A,B,C)
       CALL MAG(A,B,C,AREA1)
       CALL CROSS(B3(1),B3(2),B3(3),B5(1),B5(2),B5(3),A,B,C)
       CALL MAG(A,B,C,AREA2)
       CALL CROSS(B4(1),B4(2),B4(3),B6(1),B6(2),B6(3),A,B,C)
       CALL MAG(A,B,C,AREA3)    
       
C
C AREA DUE TO HEXAGONS
        CALL CROSS(B1(1),B1(2),B1(3),B3(1),B3(2),B3(3),A,B,C)
        CALL MAG(A,B,C,AREA4)
        CALL CROSS(B1(1),B1(2),B1(3),B4(1),B4(2),B4(3),A,B,C)
        CALL MAG(A,B,C,AREA5)
        CALL CROSS(B3(1),B3(2),B3(3),B4(1),B4(2),B4(3),A,B,C)
        CALL MAG(A,B,C,AREA6)
C        
        CALL CROSS(B1(1),B1(2),B1(3),B5(1),B5(2),B5(3),A,B,C)
        CALL MAG(A,B,C,AREA7)
        CALL CROSS(B1(1),B1(2),B1(3),B6(1),B6(2),B6(3),A,B,C)
        CALL MAG(A,B,C,AREA8)
        CALL CROSS(B5(1),B5(2),B5(3),B6(1),B6(2),B6(3),A,B,C)
        CALL MAG(A,B,C,AREA9)
C        
        CALL CROSS(B2(1),B2(2),B2(3),B3(1),B3(2),B3(3),A,B,C)
        CALL MAG(A,B,C,AREA10)
        CALL CROSS(B2(1),B2(2),B2(3),B6(1),B6(2),B6(3),A,B,C)
        CALL MAG(A,B,C,AREA11)
        CALL CROSS(B3(1),B3(2),B3(3),B6(1),B6(2),B6(3),A,B,C)
        CALL MAG(A,B,C,AREA12)
C        
        CALL CROSS(B2(1),B2(2),B2(3),B5(1),B5(2),B5(3),A,B,C)
        CALL MAG(A,B,C,AREA13)
        CALL CROSS(B2(1),B2(2),B2(3),B4(1),B4(2),B4(3),A,B,C)
        CALL MAG(A,B,C,AREA14)
        CALL CROSS(B5(1),B5(2),B5(3),B4(1),B4(2),B4(3),A,B,C)
C
        CALL MAG(A,B,C,AREA15)
        AREATOT=AREA1+AREA2+AREA3
     &     +AREA4+AREA5+AREA6+AREA7+AREA8+AREA9+AREA10
     &     +AREA11+AREA12+AREA13+AREA14+AREA15
        AREATOT=2*AREATOT
        AREARATIO=AREATOT/(6*(1.0+2*DSQRT(3.0D+00)))
C
C LENGTH
        CALL MAG(B1(1),B1(2),B1(3),L1)
        CALL MAG(B2(1),B2(2),B2(3),L2)
        CALL MAG(B3(1),B3(2),B3(3),L3)
        CALL MAG(B4(1),B4(2),B4(3),L4)
        CALL MAG(B5(1),B5(2),B5(3),L5)
        CALL MAG(B6(1),B6(2),B6(3),L6)
        LENTOT=6*(L1+L2+L3+L4+L5+L6)
        LRATIO=LENTOT/36.0D+00
C        
C

        WRITE(*,1)LRATIO,AREARATIO,S3,(360*DATAN(s3)/(2*3.14159))
2       CONTINUE
4       CONTINUE
1       FORMAT(4f10.2)
3       FORMAT('    L/L_0     A/A_0     Shear')

        RETURN
        END
C
C

C**********************************************************************
C SUBROUTINE for axisymmetric tension of randomly oriented 
C  tetrakaidecahedra
C The first tetrakaidecahedron is oriented as in 
C  the following reference:
C  S. B. Singh and H. K. D. H. Bhadeshia
C  Materials Science & Technology 14 (1998) 832-834.
C**********************************************************************

      SUBROUTINE tA()
        DOUBLE PRECISION S(9)
        DOUBLE PRECISION A1(3),A2(3),A3(3),A4(3),A5(3),A6(3)
        DOUBLE PRECISION B1(3),B2(3),B3(3),B4(3),B5(3),B6(3)
        DOUBLE PRECISION C1(3),C2(3),C3(3),C4(3),C5(3),C6(3)
        DOUBLE PRECISION D1(3),D2(3),D3(3),D4(4),D5(3),D6(3)
        DOUBLE PRECISION AREA1,AREA2,AREA3,AREA4,AREA5,AREA6
        DOUBLE PRECISION AREA7,AREA8,AREA9,AREA10,AREA11,AREA12
        DOUBLE PRECISION AREA13, AREA14,AREA15
        DOUBLE PRECISION A,B,C,AREATOT,AREARATIO
        DOUBLE PRECISION LENTOT,L1,L2,L3,L4,L5,L6,LRATIO
        DOUBLE PRECISION S1,E1,E2,E3,ES
        DOUBLE PRECISION R(9),P1,P2,P3,N,P
        INTEGER I,J
       
C    
      CALL SIGPRINT(' Axisymmetric tension                            '
     &             ,'','',.TRUE.)

      WRITE(*,3)

C THE SIX VECTORS OF TETRAKAIDECAHEDRON
C S. B. Singh and H. K. D. H. Bhadeshia
C Materials Science & Technology 14 (1998) 832-834
       DO 4 J=1,100
C       
       IF(J .EQ. 1)THEN
       A1(1)=1.0D+00
       A1(2)=0.0D+00
       A1(3)=0.0D+00
C
       A2(1)=0.0D+00
       A2(2)=1.0D+00
       A2(3)=0.0D+00
C
       A3(1)=-0.5D+00
       A3(2)=-0.5D+00
       A3(3)=1/DSQRT(2.0D+00)
C
       A4(1)=0.5D+00
       A4(2)=-0.5D+00
       A4(3)=1/DSQRT(2.0D+00)
C       
       A5(1)=0.5D+00
       A5(2)=0.5D+00
       A5(3)=1/DSQRT(2.0D+00)
C       
       A6(1)=-0.5D+00
       A6(2)=0.5D+00
       A6(3)=1/DSQRT(2.0D+00)
      
C
       ELSE
       
       P1=RAND()
       P2=RAND()
       P3=RAND()
       P=DSQRT(P1*P1+P2*P2+P3*P3)
       P1=P1/P
       P2=P2/P
       P3=P3/P
       N=2*3.14159*RAND()
       CALL ROT(P1,P2,P3,N,R)
       
       
       D1(1)=1.0D+00
       D1(2)=0.0D+00
       D1(3)=0.0D+00
C
       D2(1)=0.0D+00
       D2(2)=1.0D+00
       D2(3)=0.0D+00
C
       D3(1)=-0.5D+00
       D3(2)=-0.5D+00
       D3(3)=1/DSQRT(2.0D+00)
C
       D4(1)=0.5D+00
       D4(2)=-0.5D+00
       D4(3)=1/DSQRT(2.0D+00)
C       
       D5(1)=0.5D+00
       D5(2)=0.5D+00
       D5(3)=1/DSQRT(2.0D+00)
C       
       D6(1)=-0.5D+00
       D6(2)=0.5D+00
       D6(3)=1/DSQRT(2.0D+00)
C
       CALL TRANS(R,D1(1),D1(2),D1(3),A1(1),A1(2),A1(3))
       CALL TRANS(R,D2(1),D2(2),D2(3),A2(1),A2(2),A2(3))
       CALL TRANS(R,D3(1),D3(2),D3(3),A3(1),A3(2),A3(3))
       CALL TRANS(R,D4(1),D4(2),D4(3),A4(1),A4(2),A4(3))
       CALL TRANS(R,D5(1),D5(2),D5(3),A5(1),A5(2),A5(3))
       CALL TRANS(R,D6(1),D6(2),D6(3),A6(1),A6(2),A6(3))
       ENDIF
C
      DO 2 I=1,16
       S1=(I-1)*1.0D+00
         
C
C DEFORMATION MATRIX
       S(1)=1.0d+00 + S1
       S(2)=0.0d+00
       S(3)=0.0D+00
       S(4)=0.0d+00
       S(5)=1.0d+00/DSQRT(S(1))
       S(6)=0.0D+00
       S(7)=0.0D+00
       S(8)=0.0D+00
       S(9)=1.0D+00/DSQRT(S(1))


       E1=DLOG(S(1))
       E2=DLOG(S(5))
       E3=DLOG(S(9))
       ES=DSQRT((2.0D+00/3.0D+00)*(E1*E1+E2*E2+E3*E3))
       
C
C VECTORS AFTER DEFORMATION
       CALL TRANS(S,A1(1),A1(2),A1(3),B1(1),B1(2),B1(3))
       CALL TRANS(S,A2(1),A2(2),A2(3),B2(1),B2(2),B2(3))
       CALL TRANS(S,A3(1),A3(2),A3(3),B3(1),B3(2),B3(3))
       CALL TRANS(S,A4(1),A4(2),A4(3),B4(1),B4(2),B4(3))
       CALL TRANS(S,A5(1),A5(2),A5(3),B5(1),B5(2),B5(3))
       CALL TRANS(S,A6(1),A6(2),A6(3),B6(1),B6(2),B6(3))
C
C AREA DUE TO SQUARES
       CALL CROSS(B1(1),B1(2),B1(3),B2(1),B2(2),B2(3),A,B,C)
       CALL MAG(A,B,C,AREA1)
       CALL CROSS(B3(1),B3(2),B3(3),B5(1),B5(2),B5(3),A,B,C)
       CALL MAG(A,B,C,AREA2)
       CALL CROSS(B4(1),B4(2),B4(3),B6(1),B6(2),B6(3),A,B,C)
       CALL MAG(A,B,C,AREA3)    
       
C
C AREA DUE TO HEXAGONS
        CALL CROSS(B1(1),B1(2),B1(3),B3(1),B3(2),B3(3),A,B,C)
        CALL MAG(A,B,C,AREA4)
        CALL CROSS(B1(1),B1(2),B1(3),B4(1),B4(2),B4(3),A,B,C)
        CALL MAG(A,B,C,AREA5)
        CALL CROSS(B3(1),B3(2),B3(3),B4(1),B4(2),B4(3),A,B,C)
        CALL MAG(A,B,C,AREA6)
C        
        CALL CROSS(B1(1),B1(2),B1(3),B5(1),B5(2),B5(3),A,B,C)
        CALL MAG(A,B,C,AREA7)
        CALL CROSS(B1(1),B1(2),B1(3),B6(1),B6(2),B6(3),A,B,C)
        CALL MAG(A,B,C,AREA8)
        CALL CROSS(B5(1),B5(2),B5(3),B6(1),B6(2),B6(3),A,B,C)
        CALL MAG(A,B,C,AREA9)
C        
        CALL CROSS(B2(1),B2(2),B2(3),B3(1),B3(2),B3(3),A,B,C)
        CALL MAG(A,B,C,AREA10)
        CALL CROSS(B2(1),B2(2),B2(3),B6(1),B6(2),B6(3),A,B,C)
        CALL MAG(A,B,C,AREA11)
        CALL CROSS(B3(1),B3(2),B3(3),B6(1),B6(2),B6(3),A,B,C)
        CALL MAG(A,B,C,AREA12)
C        
        CALL CROSS(B2(1),B2(2),B2(3),B5(1),B5(2),B5(3),A,B,C)
        CALL MAG(A,B,C,AREA13)
        CALL CROSS(B2(1),B2(2),B2(3),B4(1),B4(2),B4(3),A,B,C)
        CALL MAG(A,B,C,AREA14)
        CALL CROSS(B5(1),B5(2),B5(3),B4(1),B4(2),B4(3),A,B,C)
C
        CALL MAG(A,B,C,AREA15)
        AREATOT=AREA1+AREA2+AREA3
     &     +AREA4+AREA5+AREA6+AREA7+AREA8+AREA9+AREA10
     &     +AREA11+AREA12+AREA13+AREA14+AREA15
        AREATOT=2*AREATOT
        AREARATIO=AREATOT/(6*(1.0+2*DSQRT(3.0D+00)))
C
C LENGTH
        CALL MAG(B1(1),B1(2),B1(3),L1)
        CALL MAG(B2(1),B2(2),B2(3),L2)
        CALL MAG(B3(1),B3(2),B3(3),L3)
        CALL MAG(B4(1),B4(2),B4(3),L4)
        CALL MAG(B5(1),B5(2),B5(3),L5)
        CALL MAG(B6(1),B6(2),B6(3),L6)
        LENTOT=6*(L1+L2+L3+L4+L5+L6)
        LRATIO=LENTOT/36.0D+00
C        
C

        WRITE(*,1)LRATIO,AREARATIO,E1,E2,E3,ES
2       CONTINUE
4       CONTINUE
1       FORMAT(6f10.2)
3       FORMAT('    L/L_0     A/A_0     S_11      S_22      S_33
     &Eq')

        RETURN
        END
C
C

C**********************************************************************
C SUBROUTINE for plane strain deformation combined with SHEAR
C of randomly oriented tetrakaidecahedra
C Shear strain constant. Shear strain = S_11*S_13
C The first tetrakaidecahedron is oriented as in 
C  the following reference:
C  S. B. Singh and H. K. D. H. Bhadeshia
C  Materials Science & Technology 14 (1998) 832-834.
C**********************************************************************

      SUBROUTINE tsPS()
        DOUBLE PRECISION S(9)
        DOUBLE PRECISION A1(3),A2(3),A3(3),A4(3),A5(3),A6(3)
        DOUBLE PRECISION B1(3),B2(3),B3(3),B4(3),B5(3),B6(3)
        DOUBLE PRECISION C1(3),C2(3),C3(3),C4(3),C5(3),C6(3)
        DOUBLE PRECISION D1(3),D2(3),D3(3),D4(4),D5(3),D6(3)
        DOUBLE PRECISION AREA1,AREA2,AREA3,AREA4,AREA5,AREA6
        DOUBLE PRECISION AREA7,AREA8,AREA9,AREA10,AREA11,AREA12
        DOUBLE PRECISION AREA13, AREA14,AREA15
        DOUBLE PRECISION A,B,C,AREATOT,AREARATIO
        DOUBLE PRECISION LENTOT,L1,L2,L3,L4,L5,L6,LRATIO
        DOUBLE PRECISION S1,S9,E1,E2,E3,ES,shear
        DOUBLE PRECISION R(9),P1,P2,P3,N,P
        INTEGER I,J,K
       
C    
      CALL SIGPRINT(' Plane strain deformation combined with SHEAR    '
     &             ,'','',.TRUE.)

      WRITE(*,3)

C THE SIX VECTORS OF TETRAKAIDECAHEDRON
C S. B. Singh and H. K. D. H. Bhadeshia
C Materials Science & Technology 14 (1998) 832-834
       DO 4 J=1,1
C       
       IF(J .EQ. 1)THEN
       A1(1)=1.0D+00
       A1(2)=0.0D+00
       A1(3)=0.0D+00
C
       A2(1)=0.0D+00
       A2(2)=1.0D+00
       A2(3)=0.0D+00
C
       A3(1)=-0.5D+00
       A3(2)=-0.5D+00
       A3(3)=1/DSQRT(2.0D+00)
C
       A4(1)=0.5D+00
       A4(2)=-0.5D+00
       A4(3)=1/DSQRT(2.0D+00)
C       
       A5(1)=0.5D+00
       A5(2)=0.5D+00
       A5(3)=1/DSQRT(2.0D+00)
C       
       A6(1)=-0.5D+00
       A6(2)=0.5D+00
       A6(3)=1/DSQRT(2.0D+00)
      
C
       ELSE
       
       P1=RAND()
       P2=RAND()
       P3=RAND()
       P=DSQRT(P1*P1+P2*P2+P3*P3)
       P1=P1/P
       P2=P2/P
       P3=P3/P
       N=2*3.14159*RAND()
       CALL ROT(P1,P2,P3,N,R)
       
       
       D1(1)=1.0D+00
       D1(2)=0.0D+00
       D1(3)=0.0D+00
C
       D2(1)=0.0D+00
       D2(2)=1.0D+00
       D2(3)=0.0D+00
C
       D3(1)=-0.5D+00
       D3(2)=-0.5D+00
       D3(3)=1/DSQRT(2.0D+00)
C
       D4(1)=0.5D+00
       D4(2)=-0.5D+00
       D4(3)=1/DSQRT(2.0D+00)
C       
       D5(1)=0.5D+00
       D5(2)=0.5D+00
       D5(3)=1/DSQRT(2.0D+00)
C       
       D6(1)=-0.5D+00
       D6(2)=0.5D+00
       D6(3)=1/DSQRT(2.0D+00)
C
       CALL TRANS(R,D1(1),D1(2),D1(3),A1(1),A1(2),A1(3))
       CALL TRANS(R,D2(1),D2(2),D2(3),A2(1),A2(2),A2(3))
       CALL TRANS(R,D3(1),D3(2),D3(3),A3(1),A3(2),A3(3))
       CALL TRANS(R,D4(1),D4(2),D4(3),A4(1),A4(2),A4(3))
       CALL TRANS(R,D5(1),D5(2),D5(3),A5(1),A5(2),A5(3))
       CALL TRANS(R,D6(1),D6(2),D6(3),A6(1),A6(2),A6(3))
       ENDIF
C vary shear strain
      DO 5 K=0,16
      shear=K*1.0d+00
C
      DO 2 I=1,12
         S1=I*1.0D+00
         S9=1.0D+00/S1
C
C DEFORMATION MATRIX
       S(1)=1.0d+00*S1
       S(2)=0.0d+00
       S(3)=shear/S(1)
       S(4)=0.0d+00
       S(5)=1.0D+00
       S(6)=0.0D+00
       S(7)=0.0D+00
       S(8)=0.0D+00
       S(9)=1.0D+00*S9
       E1=DLOG(S(1))
       E2=DLOG(S(5))
       E3=DLOG(S(9))
       ES=DSQRT((2.0D+00/3.0D+00)*(E1*E1+E2*E2+E3*E3+0.5*S(3)*S(3)))
       
C
C VECTORS AFTER DEFORMATION
       CALL TRANS(S,A1(1),A1(2),A1(3),B1(1),B1(2),B1(3))
       CALL TRANS(S,A2(1),A2(2),A2(3),B2(1),B2(2),B2(3))
       CALL TRANS(S,A3(1),A3(2),A3(3),B3(1),B3(2),B3(3))
       CALL TRANS(S,A4(1),A4(2),A4(3),B4(1),B4(2),B4(3))
       CALL TRANS(S,A5(1),A5(2),A5(3),B5(1),B5(2),B5(3))
       CALL TRANS(S,A6(1),A6(2),A6(3),B6(1),B6(2),B6(3))
C
C AREA DUE TO SQUARES
       CALL CROSS(B1(1),B1(2),B1(3),B2(1),B2(2),B2(3),A,B,C)
       CALL MAG(A,B,C,AREA1)
       CALL CROSS(B3(1),B3(2),B3(3),B5(1),B5(2),B5(3),A,B,C)
       CALL MAG(A,B,C,AREA2)
       CALL CROSS(B4(1),B4(2),B4(3),B6(1),B6(2),B6(3),A,B,C)
       CALL MAG(A,B,C,AREA3)    
       
C
C AREA DUE TO HEXAGONS
        CALL CROSS(B1(1),B1(2),B1(3),B3(1),B3(2),B3(3),A,B,C)
        CALL MAG(A,B,C,AREA4)
        CALL CROSS(B1(1),B1(2),B1(3),B4(1),B4(2),B4(3),A,B,C)
        CALL MAG(A,B,C,AREA5)
        CALL CROSS(B3(1),B3(2),B3(3),B4(1),B4(2),B4(3),A,B,C)
        CALL MAG(A,B,C,AREA6)
C        
        CALL CROSS(B1(1),B1(2),B1(3),B5(1),B5(2),B5(3),A,B,C)
        CALL MAG(A,B,C,AREA7)
        CALL CROSS(B1(1),B1(2),B1(3),B6(1),B6(2),B6(3),A,B,C)
        CALL MAG(A,B,C,AREA8)
        CALL CROSS(B5(1),B5(2),B5(3),B6(1),B6(2),B6(3),A,B,C)
        CALL MAG(A,B,C,AREA9)
C        
        CALL CROSS(B2(1),B2(2),B2(3),B3(1),B3(2),B3(3),A,B,C)
        CALL MAG(A,B,C,AREA10)
        CALL CROSS(B2(1),B2(2),B2(3),B6(1),B6(2),B6(3),A,B,C)
        CALL MAG(A,B,C,AREA11)
        CALL CROSS(B3(1),B3(2),B3(3),B6(1),B6(2),B6(3),A,B,C)
        CALL MAG(A,B,C,AREA12)
C        
        CALL CROSS(B2(1),B2(2),B2(3),B5(1),B5(2),B5(3),A,B,C)
        CALL MAG(A,B,C,AREA13)
        CALL CROSS(B2(1),B2(2),B2(3),B4(1),B4(2),B4(3),A,B,C)
        CALL MAG(A,B,C,AREA14)
        CALL CROSS(B5(1),B5(2),B5(3),B4(1),B4(2),B4(3),A,B,C)
C
        CALL MAG(A,B,C,AREA15)
        AREATOT=AREA1+AREA2+AREA3
     &     +AREA4+AREA5+AREA6+AREA7+AREA8+AREA9+AREA10
     &     +AREA11+AREA12+AREA13+AREA14+AREA15
        AREATOT=2*AREATOT
        AREARATIO=AREATOT/(6*(1.0+2*DSQRT(3.0D+00)))
C
C LENGTH
        CALL MAG(B1(1),B1(2),B1(3),L1)
        CALL MAG(B2(1),B2(2),B2(3),L2)
        CALL MAG(B3(1),B3(2),B3(3),L3)
        CALL MAG(B4(1),B4(2),B4(3),L4)
        CALL MAG(B5(1),B5(2),B5(3),L5)
        CALL MAG(B6(1),B6(2),B6(3),L6)
        LENTOT=6*(L1+L2+L3+L4+L5+L6)
        LRATIO=LENTOT/36.0D+00
C        
C
        WRITE(*,1)LRATIO,AREARATIO,log(S(1)),S(1)*S(3)
2       CONTINUE
5       CONTINUE
4       CONTINUE
1       FORMAT(4f10.2)
3       FORMAT('    L/L_0     A/A_0     log(S1)   Shear')

        RETURN
        END
C
C
C*****************************************************************
C SUBROUTINE for plane strain deformation of Needle
C  Plates are randomly oriented with respect to the 
C  deformation axes.
C*****************************************************************
       SUBROUTINE pPSNEEDLE()
        DOUBLE PRECISION S(9)
        DOUBLE PRECISION A1(3),A2(3),A3(3)
        DOUBLE PRECISION B1(3),B2(3),B3(3)
        DOUBLE PRECISION C1(3),C2(3),C3(3)
        DOUBLE PRECISION D1(3),D2(3),D3(3)
        DOUBLE PRECISION AREA1,AREA2,AREA3
        DOUBLE PRECISION A,B,C,AREATOT,AREARATIO
        DOUBLE PRECISION LENTOT,L1,L2,L3,L4,L5,L6,LRATIO
        DOUBLE PRECISION S1,S9,E1,E2,E3,ES
        DOUBLE PRECISION R(9),P1,P2,P3,N,P
        INTEGER I,J       
C
C FOR PRINTING SIGNATURE OF THIS ROUTINE     
        CALL SIGPRINT(' Plane strain deformation of Needle             '
     &               ,'Plates are randomly oriented with respect       '
     &               ,'to the deformation axes                         '
     &               ,.FALSE.)
      
       WRITE(*,3)

C THE THREE VECTORS OF A PLATE, z being the thickness direction
C
       DO 4 J=1,100
C       
       IF(J .EQ. 1)THEN
       A1(1)=1.0D+00
       A1(2)=0.0D+00
       A1(3)=0.0D+00
C
       A2(1)=0.0D+00
       A2(2)=0.05D+00
       A2(3)=0.0D+00
C
       A3(1)=0.0D+00
       A3(2)=0.0D+00
       A3(3)=0.05D+00

      
C
       ELSE
       
       P1=RAND()
       P2=RAND()
       P3=RAND()
       P=DSQRT(P1*P1+P2*P2+P3*P3)
       P1=P1/P
       P2=P2/P
       P3=P3/P
       N=2*3.14159*RAND()
       CALL ROT(P1,P2,P3,N,R)
       
       
       D1(1)=1.0D+00
       D1(2)=0.0D+00
       D1(3)=0.0D+00
C
       D2(1)=0.0D+00
       D2(2)=0.05D+00
       D2(3)=0.0D+00
C
       D3(1)=0.0D+00
       D3(2)=0.0D+00
       D3(3)=0.05D+00

       CALL TRANS(R,D1(1),D1(2),D1(3),A1(1),A1(2),A1(3))
       CALL TRANS(R,D2(1),D2(2),D2(3),A2(1),A2(2),A2(3))
       CALL TRANS(R,D3(1),D3(2),D3(3),A3(1),A3(2),A3(3))
       ENDIF
C
C vary strain
      DO 2 I=1,12
         S1=I*1.0D+00
         S9=1.0D+00/S1
C
C DEFORMATION MATRIX
       S(1)=1.0d+00*S1
       S(2)=0.0d+00
       S(3)=0.0d+00
       S(4)=0.0d+00
       S(5)=1.0D+00
       S(6)=0.0D+00
       S(7)=0.0D+00
       S(8)=0.0D+00
       S(9)=1.0D+00*S9
       E1=DLOG(S(1))
       E2=DLOG(S(5))
       E3=DLOG(S(9))
       ES=DSQRT((2.0D+00/3.0D+00)*(E1*E1+E2*E2+E3*E3))
       
C
C VECTORS AFTER DEFORMATION
       CALL TRANS(S,A1(1),A1(2),A1(3),B1(1),B1(2),B1(3))
       CALL TRANS(S,A2(1),A2(2),A2(3),B2(1),B2(2),B2(3))
       CALL TRANS(S,A3(1),A3(2),A3(3),B3(1),B3(2),B3(3))
C
C AREA DUE TO RECTAngles
       CALL CROSS(B1(1),B1(2),B1(3),B2(1),B2(2),B2(3),A,B,C)
       CALL MAG(A,B,C,AREA1)
       CALL CROSS(B2(1),B2(2),B2(3),B3(1),B3(2),B3(3),A,B,C)
       CALL MAG(A,B,C,AREA2)
       CALL CROSS(B3(1),B3(2),B3(3),B1(1),B1(2),B1(3),A,B,C)
       CALL MAG(A,B,C,AREA3)    
       
C
C
        AREATOT=AREA1+AREA2+AREA3
        AREATOT=2*AREATOT
        AREARATIO=AREATOT/(2*(0.05+0.05+0.0025))
C
C LENGTH
        CALL MAG(B1(1),B1(2),B1(3),L1)
        CALL MAG(B2(1),B2(2),B2(3),L2)
        CALL MAG(B3(1),B3(2),B3(3),L3)
        LENTOT=2*(L1+L2+L3)
        LRATIO=LENTOT/(2*(1+0.05+0.05))
C        
C

        WRITE(*,1)LRATIO,AREARATIO,E1,ES
2       CONTINUE
4       CONTINUE
1       FORMAT(4f10.2)
3       FORMAT('    L/L_0     A/A_0     STRAIN   EQ.STRAIN')

        RETURN
        END
C
C

C These SUBROUTINEs are shared by all program routines.

C*****************************************************************
      SUBROUTINE MAG(H,K,L,MAGNITUDE)
      DOUBLE PRECISION  H,K,L,MAGNITUDE
      MAGNITUDE=DSQRT(H*H+K*K+L*L)
      RETURN
      END
C*****************************************************************
      SUBROUTINE CROSS(H1,K1,L1,H2,K2,L2,H3,K3,L3)
      DOUBLE PRECISION H1,K1,L1,H2,K2,L2,H3,K3,L3
      H3=K1*L2-L1*K2
      K3=L1*H2-H1*L2
      L3=H1*K2-K1*H2
      RETURN
      END
C*****************************************************************
      SUBROUTINE DET(G,DEL)
      DOUBLE PRECISION G(9),DEL
      DEL=G(1)*(G(5)*G(9)-G(6)*G(8))
     &+G(2)*(G(6)*G(7)-G(4)*G(9))
     &+G(3)*(G(4)*G(8)-G(7)*G(5))
      RETURN
      END
C*****************************************************************
      SUBROUTINE PROD(A,B,C)
      DOUBLE PRECISION A(9),B(9),C(9)
      A(1)=B(1)*C(1)+B(2)*C(4)+B(3)*C(7)
      A(2)=B(1)*C(2)+B(2)*C(5)+B(3)*C(8)
      A(3)=B(1)*C(3)+B(2)*C(6)+B(3)*C(9)
      A(4)=B(4)*C(1)+B(5)*C(4)+B(6)*C(7)
      A(5)=B(4)*C(2)+B(5)*C(5)+B(6)*C(8)
      A(6)=B(4)*C(3)+B(5)*C(6)+B(6)*C(9)
      A(7)=B(7)*C(1)+B(8)*C(4)+B(9)*C(7)
      A(8)=B(7)*C(2)+B(8)*C(5)+B(9)*C(8)
      A(9)=B(7)*C(3)+B(8)*C(6)+B(9)*C(9)
      RETURN
      END
C----------------------------------------------------------------
      SUBROUTINE ROT(P1,P2,P3,THETA,R)
      DOUBLE PRECISION P1,P2,P3,THETA,A5
      DOUBLE PRECISION R(9)
      A5=1.0
      R(1)=P1*P1*(A5-COS(THETA))+COS(THETA)
      R(2)=P1*P2*(A5-COS(THETA))-P3*SIN(THETA)
      R(3)=P1*P3*(A5-COS(THETA))+P2*SIN(THETA)
      R(4)=P2*P1*(A5-COS(THETA))+P3*SIN(THETA)
      R(5)=P2*P2*(A5-COS(THETA))+COS(THETA)
      R(6)=P2*P3*(A5-COS(THETA))-P1*SIN(THETA)
      R(7)=P3*P1*(A5-COS(THETA))-P2*SIN(THETA)
      R(8)=P3*P2*(A5-COS(THETA))+P1*SIN(THETA)
      R(9)=P3*P3*(A5-COS(THETA))+COS(THETA)
      RETURN
      END
C*****************************************************************
      SUBROUTINE TRANS(LR,X1,X2,X3,X4,X5,X6)
      DOUBLE PRECISION LR(9),X1,X2,X3,X4,X5,X6
      X4=LR(1)*X1+LR(2)*X2+LR(3)*X3
      X5=LR(4)*X1+LR(5)*X2+LR(6)*X3
      X6=LR(7)*X1+LR(8)*X2+LR(9)*X3
      RETURN
      END
C********************************************************************
      SUBROUTINE REED(A)
      DOUBLE PRECISION A
996   READ(*,*,ERR=999)A
          GOTO 998
999       WRITE(*,997)
997       FORMAT(19X,' Incorrect Input. Try again'/)
          GOTO 996
998   RETURN
      END
C********************************************************************
      SUBROUTINE REEDI(I)
      INTEGER I
996   READ(*,*,ERR=999)I
          GOTO 998
999       WRITE(*,997)
997       FORMAT(19X,' Incorrect Input. Try again'/)
          GOTO 996
998   RETURN
      END
C*****************************************************************
C Subroutine for printing signature
C (The format of parameters is fixed : 48 characters)
C     
      SUBROUTINE SIGPRINT(routineNAME,REF1,REF2,TetraFLAG)
      CHARACTER*48 routineNAME,REF1,REF2
      LOGICAL TetraFLAG

C common Printing
      
      WRITE(*,*) '****************************************************'
      WRITE(*,*) 'Result for'
      WRITE(*,*) routineNAME

C  for deformations of tetrakaidecahedron      

      IF (TetraFLAG) THEN
       WRITE(*,*) ' of randomly oriented tetrakaidecahedra'
       WRITE(*,*) 'The first tetrakaidecahedron is oriented as in' 
       WRITE(*,*) 'the following reference:'
       WRITE(*,*) ' S. B. Singh and H. K. D. H. Bhadeshia'
       WRITE(*,*) ' Materials Science & Technology 14 (1998) 832-834.'

C  for other things      

      ELSE
       WRITE(*,*) REF1
       WRITE(*,*) REF2
      ENDIF
      WRITE(*,*) '****************************************************'

      RETURN
      END
